<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="53"/>
        <location filename="../about.ui" line="109"/>
        <location filename="../about.ui" line="165"/>
        <source>icon</source>
        <translation>icon</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Traductores</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Buscador de vídeos de YouTube%1 de SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Based on UMPlayer</source>
        <translation>Basado en UMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Versión: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Edición Portable</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Compilado con Qt %1 (usando %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our web for updates:</source>
        <translation>Visita nuestra web para conseguir actualizaciones:</translation>
    </message>
    <message>
        <source>The following people have contributed with translations:</source>
        <translation type="obsolete">Las siguientes personas han contribuido con traducciones:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="98"/>
        <source>Spanish</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="115"/>
        <source>Russian</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="108"/>
        <source>Lithuanian</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="102"/>
        <source>Japanese</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <source>Simplified-Chinese</source>
        <translation type="obsolete">Chino simplificado</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>Basque</source>
        <translation>Vasco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="104"/>
        <source>Portuguese</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="119"/>
        <source>Hungarian</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="114"/>
        <source>Polish</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="131"/>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="111"/>
        <source>Hebrew</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation type="obsolete">Portugués (Brasil)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="106"/>
        <source>Ukrainian</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="125"/>
        <source>Norwegian Nynorsk</source>
        <translation>Nynorsk</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="101"/>
        <source>Czech</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="92"/>
        <source>Many people contributed with translations.</source>
        <translation>Muchas personas han contribuido con traducciones.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="93"/>
        <source>You can also help to translate SMPlayer into your own language.</source>
        <translation>Tú también puedes ayudar a traducir el SMPlayer a tu propio idioma.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Visita %1 y únete a un equipo de traducción.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="96"/>
        <source>Current translators from the transifex teams:</source>
        <translation>Traductores actuales de los equipos de transifex:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="103"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="109"/>
        <source>Malay</source>
        <translation>Malayo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="110"/>
        <source>Portuguese - Brazil</source>
        <translation>Portugués - Brasil</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="112"/>
        <source>Simplified Chinese</source>
        <translation>Chino simplificado</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="116"/>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="118"/>
        <source>Danish</source>
        <translation>Danés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="122"/>
        <source>German</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="123"/>
        <source>Traditional Chinese</source>
        <translation>Chino tradicional</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="126"/>
        <source>Swedish</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="129"/>
        <source>Arabic - Saudi Arabia</source>
        <translation>Árabe - Arabia Saudita</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="130"/>
        <source>Sinhala</source>
        <translation>Cingalés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="132"/>
        <source>Estonian</source>
        <translation>Estonio</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="133"/>
        <source>N&apos;ko</source>
        <translation>N&apos;ko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="134"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="135"/>
        <source>Uzbek</source>
        <translation>Uzbeko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="136"/>
        <source>Catalan</source>
        <translation>Catalán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="137"/>
        <source>Slovak</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="138"/>
        <source>British English</source>
        <translation>Inglés Británico</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="139"/>
        <source>Albanian</source>
        <translation>Albanés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="140"/>
        <source>Dutch</source>
        <translation>Holandés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="141"/>
        <source>Romanian</source>
        <translation>Rumano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="142"/>
        <source>Khmer</source>
        <translation>Camboyano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="143"/>
        <source>Telugu</source>
        <translation>Telugú</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="144"/>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="145"/>
        <source>Malayalam</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="120"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="121"/>
        <source>Finnish</source>
        <translation>Finés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="127"/>
        <source>Arabic</source>
        <translation>Árabe</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="128"/>
        <source>Georgian</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="105"/>
        <source>Serbian</source>
        <translation>Serbio</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="100"/>
        <source>Croatian</source>
        <translation>Croata</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="124"/>
        <source>Bulgarian</source>
        <translation>Búlgaro</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="113"/>
        <source>Vietnamese</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>Indonesian</source>
        <translation>Indonesio</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="obsolete">%1y %2</translation>
    </message>
    <message>
        <source>%1, %2 and %3</source>
        <translation type="obsolete">%1, %2 y %3</translation>
    </message>
    <message>
        <source>%1, %2, %3 and %4</source>
        <translation type="obsolete">%1, %2, %3 y %4</translation>
    </message>
    <message>
        <source>%1, %2, %3, %4 and %5</source>
        <translation type="obsolete">%1, %2, %3, %4 y %5</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;: %2</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;: %2</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="170"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="107"/>
        <source>Galician</source>
        <translation>Gallego</translation>
    </message>
    <message>
        <source>&amp;Youtube</source>
        <translation type="obsolete">&amp;Youtube</translation>
    </message>
    <message>
        <source>Founded in February 2005, YouTube&amp;trade; is the world&apos;s most popular online video community, allowing millions of people to discover, watch and share originally-created videos. YouTube&amp;trade; provides a forum for people to connect, inform, and inspire others across the globe and acts as a distribution platform for original content creators and advertisers large and small.</source>
        <translation type="obsolete">Fundada en febrero de 2005, YouTube&amp;trade; es la mayor comunidad de vídeos online, permitiendo a millones de personas descubrir, ver y compartir vídeos originales. YouTube&amp;trade; proporciona un foro para que las personas puedan conectarse, informarse e inspirar a otros en todo el mundo y actúa como plataforma de distribución para creadores de contenidos originales y anunciantes grandes y pequeños.</translation>
    </message>
    <message>
        <source>By using this application you hereby agree to be bound by Google Terms of Services located at %1.</source>
        <translation type="obsolete">Al usar esta aplicación usted acepta las condiciones de servicio de Google disponibles en %1.</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="37"/>
        <source>Downloading...</source>
        <translation>Descargando...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="58"/>
        <source>Connecting to %1</source>
        <translation>Conectando con %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="126"/>
        <source>The Youtube code has been updated successfully.</source>
        <translation>El código de Youtube se ha actualizado correctamente.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="127"/>
        <source>Installed version: %1</source>
        <translation>Versión instalada: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="128"/>
        <source>Success</source>
        <translation>Operación realizada correctamente</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <source>An error happened writing %1</source>
        <translation>Ha ocurrido un error al escribir en %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Ha ocurrido un error descargando el fichero:&lt;br&gt;%1</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>Recording</source>
        <translation>Grabación</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="28"/>
        <source>&amp;Save to this folder</source>
        <translation>&amp;Grabar en esta carpeta</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="45"/>
        <source>&amp;Quality</source>
        <translation>Cali&amp;dad</translation>
    </message>
    <message>
        <source>Normal (360p)</source>
        <translation type="obsolete">Normal (360p)</translation>
    </message>
    <message>
        <source>HD (720p)</source>
        <translation type="obsolete">HD (720p)</translation>
    </message>
    <message>
        <source>Full HD (1080p)</source>
        <translation type="obsolete">Full HD (1080p)</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation type="obsolete">&amp;Formato</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation type="obsolete">MP4</translation>
    </message>
    <message>
        <source>Flv</source>
        <translation type="obsolete">Flv</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="157"/>
        <source>Standard Feeds</source>
        <translation>Feeds estándar</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="163"/>
        <source>&amp;Region:</source>
        <translation>Regió&amp;n:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="189"/>
        <source>Period of &amp;time:</source>
        <translation>Periodo de &amp;tiempo:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="80"/>
        <source>Playback</source>
        <translation>Reproducción</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="88"/>
        <source>Q&amp;uality:</source>
        <translation>Ca&amp;lidad:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="125"/>
        <source>&amp;Player:</source>
        <translation>&amp;Reproductor:</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation type="obsolete">Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation type="obsolete">Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation type="obsolete">Bélgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation type="obsolete">Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation type="obsolete">Canadá</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation type="obsolete">Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation type="obsolete">Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation type="obsolete">República Checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation type="obsolete">Egipto</translation>
    </message>
    <message>
        <source>France</source>
        <translation type="obsolete">Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation type="obsolete">Alemania</translation>
    </message>
    <message>
        <source>Great Britain</source>
        <translation type="obsolete">Gran Bretaña</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation type="obsolete">Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation type="obsolete">Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation type="obsolete">India</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation type="obsolete">Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation type="obsolete">Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation type="obsolete">Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation type="obsolete">Japón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation type="obsolete">Jordania</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation type="obsolete">Malasia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation type="obsolete">México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation type="obsolete">Marruecos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation type="obsolete">Holanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation type="obsolete">Nueva Zelanda</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation type="obsolete">Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation type="obsolete">Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation type="obsolete">Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation type="obsolete">Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation type="obsolete">Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation type="obsolete">Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation type="obsolete">Sudáfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation type="obsolete">Corea del sur</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation type="obsolete">España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation type="obsolete">Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation type="obsolete">Taiwan</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation type="obsolete">Emiratos Árabes Unidos</translation>
    </message>
    <message>
        <source>United States</source>
        <translation type="obsolete">Estados Unidos</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="40"/>
        <source>All time</source>
        <translation>Todo el tiempo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="41"/>
        <source>This month</source>
        <translation>Este mes</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="42"/>
        <source>This week</source>
        <translation>Esta semana</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="43"/>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>Low Quality (226p)</source>
        <translation type="obsolete">Baja Calidad (226p)</translation>
    </message>
    <message>
        <source>Medium Quality (360p)</source>
        <translation type="obsolete">Calidad Media (360p)</translation>
    </message>
    <message>
        <source>High Quality (480p)</source>
        <translation type="obsolete">Alta Calidad (480p)</translation>
    </message>
</context>
<context>
    <name>DownloadFile</name>
    <message>
        <location filename="../downloadfile.cpp" line="110"/>
        <source>unknown time remaining</source>
        <translation>tiempo restante desconocido</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="117"/>
        <source>%1 hours</source>
        <translation>%1 horas</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="123"/>
        <source>%1 minutes</source>
        <translation>%1 minutos</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="126"/>
        <source>%1 seconds</source>
        <translation>%1 segundos</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="127"/>
        <source>%1 remaining</source>
        <translation>faltan %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="132"/>
        <source>%1 of %2 MB</source>
        <translation>%1 de %2 MB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="138"/>
        <source>%1 of %2 KB</source>
        <translation>%1 de %2 KB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="144"/>
        <source>%1 of %2 bytes</source>
        <translation>%1 de %2 bytes</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="148"/>
        <source>%1 of unknown size</source>
        <translation>%1 de tamaño desconocido</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="153"/>
        <source>%1 MB/sec</source>
        <translation>%1 MB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="157"/>
        <source>%1 KB/sec</source>
        <translation>%1 KB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="161"/>
        <source>%1 bytes/sec</source>
        <translation>%1 bytes/s</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="54"/>
        <source>Click to select a file or folder</source>
        <translation>Haz clic para seleccionar un fichero o carpeta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Argentina</source>
        <translation type="obsolete">Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation type="obsolete">Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation type="obsolete">Bélgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation type="obsolete">Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation type="obsolete">Canadá</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation type="obsolete">Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation type="obsolete">Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation type="obsolete">República Checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation type="obsolete">Egipto</translation>
    </message>
    <message>
        <source>France</source>
        <translation type="obsolete">Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation type="obsolete">Alemania</translation>
    </message>
    <message>
        <source>Great Britain</source>
        <translation type="obsolete">Gran Bretaña</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation type="obsolete">Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation type="obsolete">Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation type="obsolete">India</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation type="obsolete">Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation type="obsolete">Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation type="obsolete">Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation type="obsolete">Japón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation type="obsolete">Jordania</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation type="obsolete">Malasia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation type="obsolete">México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation type="obsolete">Marruecos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation type="obsolete">Holanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation type="obsolete">Nueva Zelanda</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation type="obsolete">Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation type="obsolete">Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation type="obsolete">Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation type="obsolete">Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation type="obsolete">Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation type="obsolete">Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation type="obsolete">Sudáfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation type="obsolete">Corea del sur</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation type="obsolete">España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation type="obsolete">Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation type="obsolete">Taiwan</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation type="obsolete">Emiratos Árabes Unidos</translation>
    </message>
    <message>
        <source>United States</source>
        <translation type="obsolete">Estados Unidos</translation>
    </message>
</context>
<context>
    <name>RecordingDelegate</name>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Canceled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="155"/>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="159"/>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="163"/>
        <source>%1 bytes</source>
        <translation>%1 bytes</translation>
    </message>
</context>
<context>
    <name>RecordingDialog</name>
    <message>
        <location filename="../recordingdialog.cpp" line="208"/>
        <location filename="../recordingdialog.cpp" line="527"/>
        <source>Recordings</source>
        <translation>Grabaciones</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="209"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Borrar la lista</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="210"/>
        <location filename="../recordingdialog.cpp" line="658"/>
        <source>&amp;Open folder</source>
        <translation>&amp;Abrir carpeta</translation>
    </message>
    <message>
        <source>&amp;Enter URL</source>
        <translation type="obsolete">&amp;Introducir URL</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>There was an error in retrieving the download URL.</source>
        <translation>Se ha producido un error al cargar la URL de descarga.</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>Recording failed</source>
        <translation>La grabación ha fallado</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="413"/>
        <location filename="../recordingdialog.cpp" line="795"/>
        <source>Starting</source>
        <translation>Empezando</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="448"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="452"/>
        <source>Completed</source>
        <translation>Finalizado</translation>
    </message>
    <message numerus="yes">
        <location filename="../recordingdialog.cpp" line="531"/>
        <source>%1% of %n video - Recordings</source>
        <translation>
            <numerusform>%1% de %n video - Grabaciones</numerusform>
            <numerusform>%1% de %n videos - Grabaciones</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="616"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="618"/>
        <source>&amp;Remove from list</source>
        <translation>&amp;Quitar de la lista</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="639"/>
        <location filename="../recordingdialog.cpp" line="661"/>
        <source>Remove from &amp;list</source>
        <translation>Quitar de la &amp;lista</translation>
    </message>
    <message>
        <source>Enter a URL</source>
        <translation type="obsolete">Introducir URL</translation>
    </message>
    <message>
        <source>Enter a Youtube URL to download</source>
        <translation type="obsolete">Introduce una URL de Youtube para descargar</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="635"/>
        <source>&amp;Retry</source>
        <translation>&amp;Reintentar</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="657"/>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="660"/>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="742"/>
        <source>Fetching URL...</source>
        <translation>Cargando URL...</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="759"/>
        <source>File error</source>
        <translation>Error de archivo</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="760"/>
        <source>The file does not exists, would you like to remove it from the list?</source>
        <translation>El archivo no existe; ¿quieres borrarlo de la lista?</translation>
    </message>
</context>
<context>
    <name>Regions</name>
    <message>
        <location filename="../regions.cpp" line="26"/>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="27"/>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="29"/>
        <source>Belgium</source>
        <translation>Bélgica</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="30"/>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="31"/>
        <source>Canada</source>
        <translation>Canadá</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="32"/>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="33"/>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="34"/>
        <source>Czech Republic</source>
        <translation>República Checa</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="35"/>
        <source>Egypt</source>
        <translation>Egipto</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="36"/>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="37"/>
        <source>Germany</source>
        <translation>Alemania</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="38"/>
        <source>Great Britain</source>
        <translation>Gran Bretaña</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="39"/>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="40"/>
        <source>Hungary</source>
        <translation>Hungría</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="41"/>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="42"/>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="43"/>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="44"/>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="45"/>
        <source>Japan</source>
        <translation>Japón</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="46"/>
        <source>Jordan</source>
        <translation>Jordania</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="47"/>
        <source>Malaysia</source>
        <translation>Malasia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="48"/>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="49"/>
        <source>Morocco</source>
        <translation>Marruecos</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="50"/>
        <source>Netherlands</source>
        <translation>Holanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="51"/>
        <source>New Zealand</source>
        <translation>Nueva Zelanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="52"/>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="53"/>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="54"/>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="55"/>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="56"/>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="57"/>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="58"/>
        <source>South Africa</source>
        <translation>Sudáfrica</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="59"/>
        <source>South Korea</source>
        <translation>Corea del sur</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="60"/>
        <source>Spain</source>
        <translation>España</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="61"/>
        <source>Sweden</source>
        <translation>Suecia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="63"/>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="64"/>
        <source>United Arab Emirates</source>
        <translation>Emiratos Árabes Unidos</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="65"/>
        <source>United States</source>
        <translation>Estados Unidos</translation>
    </message>
</context>
<context>
    <name>YTDelegate</name>
    <message>
        <location filename="../ytdelegate.cpp" line="115"/>
        <source>%L1 views</source>
        <translation>visto %L1 veces</translation>
    </message>
</context>
<context>
    <name>YTDialog</name>
    <message>
        <location filename="../ytdialog.cpp" line="227"/>
        <source>YouTube Browser - SMPlayer</source>
        <translation>Buscador de vídeos de YouTube - SMPlayer</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="obsolete">&amp;Siguiente</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="obsolete">&amp;Anterior</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="277"/>
        <source>Settings</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="283"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="290"/>
        <source>Show recordings</source>
        <translation>Ver grabaciones</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="296"/>
        <source>Enter URL</source>
        <translation>Introducir URL</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="497"/>
        <source>Most Relevant</source>
        <translation>Más Relevante</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="501"/>
        <source>Most Recent</source>
        <translation>Más Reciente</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="505"/>
        <source>Most Viewed</source>
        <translation>Más Visto</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="509"/>
        <source>Most Popular</source>
        <translation>Más Popular</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="513"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="517"/>
        <source>Sports</source>
        <translation>Deportes</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="536"/>
        <source>Most popular sport videos on YouTube%1</source>
        <translation>Vídeos deportivos más populares en YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="537"/>
        <source>Most popular music videos on YouTube%1</source>
        <translation>Vídeos musicales más populares en YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="766"/>
        <source>R&amp;ecord audio</source>
        <translation>Grabar a&amp;udio</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="771"/>
        <source>&amp;Add URL to the SMPlayer playlist</source>
        <translation>&amp;Añadir la URL a la lista de reproducción del SMPlayer</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="839"/>
        <source>Enter a URL</source>
        <translation>Introducir URL</translation>
    </message>
    <message>
        <source>Enter a Youtube URL to download</source>
        <translation type="obsolete">Introduce una URL de Youtube para descargar</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="963"/>
        <location filename="../ytdialog.cpp" line="974"/>
        <source>Problems with Youtube</source>
        <translation>Problemas con Youtube</translation>
    </message>
    <message>
        <source>Unfortunately due to changes in Youtube page, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation type="obsolete">Lamentablemente debido a cambios en Youtube, no es posible reproducir ni descargar el vídeo &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="965"/>
        <source>Do you want to update the Youtube code? This may fix the problem.</source>
        <translation>¿Quieres actualizar el código de Youtube? Esto podría solucionar el problema.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="964"/>
        <location filename="../ytdialog.cpp" line="975"/>
        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation>Lamentablemente debido a cambios en Youtube, no es posible reproducir ni descargar el vídeo &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="840"/>
        <source>Enter a Youtube URL to record</source>
        <translation>Introduce una URL de Youtube para descargar</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="976"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Quizás el problema se podría solucionar actualizando esta aplicación.</translation>
    </message>
    <message>
        <source>Recently Featured</source>
        <translation type="obsolete">Últimos destacados</translation>
    </message>
    <message>
        <source>Most Rated</source>
        <translation type="obsolete">Mejor Calificado</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="535"/>
        <source>Most popular videos on YouTube%1</source>
        <translation>Vídeos más populares en YouTube%1</translation>
    </message>
    <message>
        <source>Most rated videos on YouTube%1</source>
        <translation type="obsolete">Vídeos mejor calificados en YouTube%1</translation>
    </message>
    <message>
        <source>Most viewed videos on YouTube%1</source>
        <translation type="obsolete">Vídeos más vistos en  YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="656"/>
        <source>Error: Could not connect to Youtube server.</source>
        <translation>Error: No se puede conectar al servidor de Youtube.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="540"/>
        <source>YouTube%2 results for &quot;%1&quot;</source>
        <translation>YouTube%2 resultados de &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Videos recently featured on YouTube%1</source>
        <translation type="obsolete">Últimos vídeos destacados en YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="664"/>
        <source>No videos found</source>
        <translation>No se han encontrado vídeos</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="666"/>
        <source>No videos found for &quot;%1&quot;</source>
        <translation>No se han encontrado vídeos para &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="763"/>
        <source>&amp;Play video</source>
        <translation>&amp;Reproducir vídeo</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="765"/>
        <source>&amp;Record video</source>
        <translation>&amp;Grabar vídeo</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="768"/>
        <source>&amp;Watch on YouTube</source>
        <translation>&amp;Ver en  YouTube</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="769"/>
        <source>&amp;Copy link</source>
        <translation>&amp;Copiar enlace</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="252"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="258"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Music Top Rated</source>
        <translation type="obsolete">Música</translation>
    </message>
    <message>
        <source>Most rated music videos this week on YouTube%1</source>
        <translation type="obsolete">Vídeos musicales mejor calificados esta semana en YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="949"/>
        <location filename="../ytdialog.cpp" line="951"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
</TS>
